==> npm-expansions-2.0.0.tgz: package/README.md <==
# npm-expansions
[![Build Status](http://img.shields.io/travis/npm/npm-expansions.svg?style=flat-square)](https://travis-ci.org/npm/npm-expansions) [![NPM version](http://img.shields.io/npm/v/npm-expansions.svg?style=flat-square)](https://www.npmjs.org/package/npm-expansions) [![NPM license](http://img.shields.io/npm/l/npm-expansions.svg?style=flat-square)](https://www.npmjs.org/package/npm-expansions)

What does n-p-m stand for?

## What This Is

This is the source code for the three-word thingies that randomly appear in the header of the [npmjs.com](https://npmjs.com) website. Examples include:

- Naughty Push Message
- Nectar of the Programming Masses
- Needless Pachouli Manufacture
- Neil Patrick's Mansion
- Never Program Mad
- Never Push to Master
- Neverending Plethora of Modules
- Newton's Programmatic Measurements
- Newts Parading Majestically
- Nice Poodle, Mister
- Nickel Plated Moose
- Nineties Party Mix
- Null Pointer Missing
- Nymphets Playing Mahjong

## How to Contribute

Add your own expansion to [index.txt](index.txt), then send us a pull request! If you think of multiple possibilities, it's best to submit them as separate PRs, as we may like some but not others.

Some other suggestions:

- be meaningful. Three random words is not good enough.
- be funny. This is very subjective, we realize, so try not to take it personally if we don't get it.
- be novel. If your expansion starts with "No", "New", "Never" or "Node" the other two words better be pretty great.
- avoid hyphenation, especially "non-". Yes, there are some in there already. Sorry.
- use actual words. You can't just make up random new words. Unless they're really good.
- Avoid names of people and products (other than npm ;-))
- avoid anything that even slightly hints of violating npm's [code of conduct](https://www.npmjs.com/policies/conduct/). These are literally the first words that appear on the website, and our audience is very broad, so it's best to avoid things that can be misconstrued.

==> npm-expansions-2.1.0.tgz: package/README.md <==
# npm-expansions
[![Build Status](http://img.shields.io/travis/npm/npm-expansions.svg?style=flat-square)](https://travis-ci.org/npm/npm-expansions) [![NPM version](http://img.shields.io/npm/v/npm-expansions.svg?style=flat-square)](https://www.npmjs.org/package/npm-expansions) [![NPM license](http://img.shields.io/npm/l/npm-expansions.svg?style=flat-square)](https://www.npmjs.org/package/npm-expansions)

What does n-p-m stand for?

## What This Is

This is the source code for the three-word thingies that randomly appear in the header of the [npmjs.com](https://npmjs.com) website. Examples include:

- Naughty Push Message
- Nectar of the Programming Masses
- Needless Pachouli Manufacture
- Neil Patrick's Mansion
- Never Program Mad
- Never Push to Master
- Neverending Plethora of Modules
- Newton's Programmatic Measurements
- Newts Parading Majestically
- Nice Poodle, Mister
- Nickel Plated Moose
- Nineties Party Mix
- Null Pointer Missing
- Nymphets Playing Mahjong

## How to Contribute

Add your own expansion to [expansions.txt](expansions.txt), then send us a pull request! If you think of multiple possibilities, it's best to submit them as separate PRs, as we may like some but not others.

Some other suggestions:

- be meaningful. Three random words is not good enough.
- be funny. This is very subjective, we realize, so try not to take it personally if we don't get it.
- be novel. If your expansion starts with "No", "New", "Never" or "Node" the other two words better be pretty great.
- avoid hyphenation, especially "non-". Yes, there are some in there already. Sorry.
- use actual words. You can't just make up random new words. Unless they're really good.
- Avoid names of people and products (other than npm ;-))
- avoid anything that even slightly hints of violating npm's [code of conduct](https://www.npmjs.com/policies/conduct/). These are literally the first words that appear on the website, and our audience is very broad, so it's best to avoid things that can be misconstrued.
